# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-10 10:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_track', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usertrackrecord',
            name='info',
            field=models.TextField(blank=True, null=True, verbose_name='\u8be6\u60c5'),
        ),
    ]
