# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-10-31 07:33
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_track', '0003_auto_20181031_1530'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='usertrackrecord',
            options={'ordering': ['-created_at'], 'permissions': (('add_user_leave', '\u53ef\u4ee5\u6dfb\u52a0\u5b66\u751f\u8bf7\u5047\u7c7b\u8db3\u8ff9'), ('view_user_leave', '\u53ef\u4ee5\u67e5\u770b\u5b66\u751f\u8bf7\u5047\u7c7b\u8db3\u8ff9'), ('add_crm_fee', '\u53ef\u4ee5\u6dfb\u52a0\u7f34\u8d39\u7c7b\u8db3\u8ff9'), ('view_crm_fee', '\u53ef\u4ee5\u67e5\u770b\u7f34\u8d39\u7c7b\u8db3\u8ff9'), ('add_crm_referral', '\u53ef\u4ee5\u6dfb\u52a0\u8f6c\u4ecb\u7c7b\u8db3\u8ff9'), ('view_crm_referral', '\u53ef\u4ee5\u67e5\u770b\u8f6c\u4ecb\u7c7b\u8db3\u8ff9'), ('add_track_other', '\u53ef\u4ee5\u6dfb\u52a0\u5176\u4ed6\u7c7b\u8db3\u8ff9'), ('view_track_other', '\u53ef\u4ee5\u67e5\u770b\u5176\u4ed6\u7c7b\u8db3\u8ff9'))},
        ),
    ]
