{% extends "bee_django_track/base.html" %}
{% load bee_django_track_filter %}

{% block content %}
    {% include 'bee_django_track/logo.html' %}
    {% include 'bee_django_track/nav.html' %}
    <div class="text-center"><h3>
        足迹详情
    </h3>
    </div>
    {#    <div class="text-right">#}
    {#        <a class="btn btn-default" href="{% url 'bee_django_track:record_add' user_id=user.id %}">添加</a>#}
    {#    </div>#}

    <table class="table">
        <tr>
            <td class="col-xs-3">类型</td>
            <td>{{ record.content_type.title }}</td>
        </tr>
        <tr>
            <td>标题</td>
            <td>{{ record.title|default:"" }}</td>
        </tr>
        <tr>
            <td>详情</td>
            <td>{{ record.info|default:"" }}</td>
        </tr>
        <tr>
            <td>添加人</td>
            <td>{{ record.created_by|get_name_detail:False|default:"系统" }}</td>
        </tr>
        <tr>
            <td>添加时间</td>
            <td>{{ record.created_at }}</td>
        </tr>

    </table>
    {% include 'bee_django_track/paginator.html' %}
{% endblock %}
{% block scripts %}
    <script>
        function click_del(_this) {
            if (!confirm('确认要执行这个操作？')) {
                return false;
            }
            var url = $(_this).attr('data-confirm');
            $.post(url).done(function (data) {
                alert('删除成功!');
                location.reload();
            });
        }
    </script>
{% endblock %}