{% load staticfiles %}
<html>
<head>
    <title>{% block title %}{% endblock %}</title>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no">
    <link rel="stylesheet" href="{% static 'bee_django_track/bootstrap/css/bootstrap.min.css' %}">
    <link rel="stylesheet" href="{% static 'bee_django_track/bootstrap/css/bootstrap-theme.min.css' %}">
    <script src="{% static 'bee_django_track/jquery/js/jquery.min.js' %}"></script>
    <script src="{% static 'bee_django_track/bootstrap/js/bootstrap.min.js' %}"></script>
    <script src="{% static 'bee_django_track/js/utils.js' %}"></script>

    {#  时间控件#}
    <link rel="stylesheet" type="text/css"
          href="{% static "bee_django_track/datetimePicker/jquery.datetimepicker.min.css" %}">
    <script src="{% static "bee_django_crm/datetimePicker/jquery.datetimepicker.full.min.js" %}"></script>
    {#二级联动联动#}
    <script type="text/javascript" src="{% static 'admin/js/vendor/jquery/jquery.min.js' %}"></script>
    <script type="text/javascript" src="{% static 'admin/js/jquery.init.js' %}"></script>

    <script type="text/javascript" src="{% static 'bee_django_track/smart-selects/admin/js/chainedfk.js' %}"></script>
    <script type="text/javascript" src="{% static 'bee_django_track/smart-selects/admin/js/bindfields.js' %}"></script>
    {#选择框筛选#}
    {#    <link href="https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.6-rc.0/css/select2.min.css" rel="stylesheet"/>#}
    {#    <script src="https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.6-rc.0/js/select2.min.js"></script>#}
    <style>
        body {
            margin: 0 auto;
            background-repeat: repeat-x;
            background-position: bottom;
        }

        .row.no-gutter {
        {#            margin-left: 0;#}{#            margin-right: 0;#}
        }

        .row.no-gutter [class*='col-']:not(:first-child),
        .row.no-gutter [class*='col-']:not(:last-child) {
            padding-right: 0;
            padding-left: 0;
        }

        .red {
            color: red;
        }
    </style>
    {% block styles %}<!--custom styles-->{% endblock %}

</head>

<body>
<div class="container">
    {% block content %}内容{% endblock %}
</div>
{% block scripts %}
    <!--custom scripts-->

{% endblock %}
<script type="text/javascript">
    $.ajaxSetup({
        data: {
            csrfmiddlewaretoken: '{{ csrf_token }}'
        }
    });
</script>
</body>
</html>
