# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-10 09:46
from __future__ import unicode_literals

import bee_django_track.models
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='ContentType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name='\u6807\u9898')),
                ('identity', models.CharField(help_text='\u6b64\u5b57\u6bb5\u552f\u4e00', max_length=180, null=True, unique=True, verbose_name='\u6807\u8bc6\u7b26')),
                ('app_label', models.CharField(blank=True, max_length=180, null=True, verbose_name='app\u540d')),
                ('model', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u6a21\u5757\u540d')),
                ('user_field', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u7528\u6237\u5b57\u6bb5\u540d')),
                ('link', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u94fe\u63a5')),
                ('link_type', models.IntegerField(default=1)),
                ('info', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u5907\u6ce8')),
                ('is_add', models.BooleanField(default=True, verbose_name='\u662f\u5426\u53ef\u6dfb\u52a0')),
                ('is_edit', models.BooleanField(default=True, verbose_name='\u662f\u5426\u53ef\u4fee\u6539')),
            ],
            options={
                'ordering': ['id'],
                'db_table': 'bee_django_track_content_type',
            },
        ),
        migrations.CreateModel(
            name='UserTrackRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name='\u6807\u9898')),
                ('info', models.TextField(verbose_name='\u8be6\u60c5')),
                ('content_id', models.IntegerField(null=True, verbose_name=bee_django_track.models.ContentType)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_track.ContentType', verbose_name='\u7c7b\u578b')),
                ('created_by', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='create_by_user', to=settings.AUTH_USER_MODEL, verbose_name='\u7531\u8c01\u6dfb\u52a0')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='\u7528\u6237')),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_track_record',
            },
        ),
        migrations.AlterUniqueTogether(
            name='contenttype',
            unique_together=set([('app_label', 'model')]),
        ),
    ]
